#
# spec file for package python-Babel
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-Babel
Version:        2.3.4
Release:        2.4
Url:            http://babel.pocoo.org/
Summary:        Internationalization utilities
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/6e/96/ba2a2462ed25ca0e651fb7b66e7080f5315f91425a07ea5b34d7c870c114/Babel-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# Test requirements:
BuildRequires:  python-py >= 1.4.14
BuildRequires:  python-pytest >= 2.3.5
BuildRequires:  python-pytz
Requires:       python-pytz
# absolute path will work cross-distro at least on RHEL and SUSE
Requires(post): /usr/sbin/update-alternatives
Requires(postun): /usr/sbin/update-alternatives
Provides:       python-babel = %{version}
Obsoletes:      python-babel < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-argparse
Requires:       python-argparse
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
A collection of tools for internationalizing Python applications.

%prep
%setup -q -n Babel-%{version}
sed -i "s/pybabel =/pybabel-%{py_ver} =/" setup.py

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/pybabel
ln -sf %{_sysconfdir}/alternatives/pybabel %{buildroot}%{_bindir}/pybabel

%fdupes %{buildroot}%{python_sitelib}

%check
TZ=UTC LC_ALL=C py.test tests

%pre
# Since /usr/bin/pybabel became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/pybabel ] || rm -f %{_bindir}/pybabel

%post
update-alternatives --install %{_bindir}/pybabel pybabel %{_bindir}/pybabel-%{py_ver} 30

%postun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove pybabel %{_bindir}/pybabel-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc LICENSE CHANGES
%ghost %{_sysconfdir}/alternatives/pybabel
%{_bindir}/pybabel
%{_bindir}/pybabel-%{py_ver}
%{python_sitelib}/*

%changelog
* Mon May  2 2016 dmueller@suse.com
- update to 2.3.4:
  * CLDR: The lxml library is no longer used for CLDR importing, so it should not cause strange failures e
  * CLI: Every last single CLI usage regression should now be gone, and both distutils and stand-alone CLI
  * CLI: Usage regressions that had snuck in between 2.2 and 2.3 should be no more. (https://github.com/py
  * Dates: Period (am/pm) formatting was broken in certain locales (namely zh_TW). Thanks to @jun66j5 for
  * CLDR: Add an API for territory language data (https://github.com/python-babel/babel/pull/315)
  * Core: Character order and measurement system data is imported and exposed (https://github.com/python-b
  * Dates: Add an API for time interval formatting (https://github.com/python-babel/babel/pull/316)
  * Dates: More pattern formats and lengths are supported (https://github.com/python-babel/babel/pull/347)
  * Dates: Period IDs are imported and exposed (https://github.com/python-babel/babel/pull/349)
  * Dates: Support for date-time skeleton formats has been added (https://github.com/python-babel/babel/pu
  * Dates: Timezone formatting has been improved (https://github.com/python-babel/babel/pull/338)
  * Messages: JavaScript extraction now supports dotted names, ES6 template strings and JSX tags (https://
- drop fix-timezone-test.patch skip-dst-tests.patch, no longer necessary
* Mon Feb  1 2016 toddrme2178@gmail.com
- update to version 2.2.0:
  * Bugfixes
    + General: Add __hash__ to Locale. (#303) (2aa8074)
    + General: Allow files with BOM if they're UTF-8 (#189) (da87edd)
    + General: localedata directory is now locale-data (#109)
    (2d1882e)
    + General: odict: Fix pop method (0a9e97e)
    + General: Removed uses of datetime.date class from *.dat files
    (#174) (94f6830)
    + Messages: Fix plural selection for chinese (531f666)
    + Messages: Fix typo and add semicolon in plural_forms (5784501)
    + Messages: Flatten NullTranslations.files into a list (ad11101)
    + Times: FixedOffsetTimezone: fix display of negative offsets
    (d816803)
  * Features
    + CLDR: Update to CLDR 28 (#292) (9f7f4d0)
    + General: Add __copy__ and __deepcopy__ to LazyProxy. (a1cc3f1)
    + General: Add official support for Python 3.4 and 3.5
    + General: Improve odict performance by making key search O(1)
    (6822b7f)
    + Locale: Add an ordinal_form property to Locale (#270) (b3f3430)
    + Locale: Add support for list formatting (37ce4fa, be6e23d)
    + Locale: Check inheritance exceptions first (3ef0d6d)
    + Messages: Allow file locations without line numbers (#279)
    (79bc781)
    + Messages: Allow passing a callable to `extract()` (#289)
    (3f58516)
    + Messages: Support 'Language' header field of PO files (#76)
    (3ce842b)
    + Messages: Update catalog headers from templates (e0e7ef1)
    + Numbers: Properly load and expose currency format types (#201)
    (df676ab)
    + Numbers: Use cdecimal by default when available (b6169be)
    + Numbers: Use the CLDR's suggested number of decimals for
    format_currency (#139) (201ed50)
    + Times: Add format_timedelta(format='narrow') support (edc5eb5)
- update to version 2.1.1:
  * Fix Locale.parse using "global.dat" incompatible types
    (https://github.com/python-babel/babel/issues/174)
  * Fix display of negative offsets in "FixedOffsetTimezone"
    (https://github.com/python-babel/babel/issues/214)
  * Improved odict performance which is used during localization file
    build, should improve compilation time for large projects
  * Add support for "narrow" format for "format_timedelta"
  * Add universal wheel support
  * Support 'Language' header field in .PO files
    (fixes https://github.com/python-babel/babel/issues/76)
  * Test suite enhancements (coverage, broken tests fixed, etc)
  * Documentation updated
- changes from version 2.0:
  * Added support for looking up currencies that belong to a territory
    through the :func:`babel.numbers.get_territory_currencies`
    function.
  * Improved Python 3 support.
  * Fixed some broken tests for timezone behavior.
  * Improved various smaller things for dealing with dates.
- changes from version 1.4:
  * Fixed a bug that caused deprecated territory codes not being
    converted properly by the subtag resolving.  This for instance
    showed up when trying to use "und_UK" as a language code
    which now properly resolves to "en_GB".
  * Fixed a bug that made it impossible to import the CLDR data
    from scratch on windows systems.
- fix update-alternatives
- add skip-dst-tests.patch: drop DST related tests (workaround
  issue #156)
- Add fix-timezone-test.patch: already included upstream
- Remove 0001-disable_timezone_tests.patch in favor of
  fix-timezone-test.patch
* Fri Jul 24 2015 seife+obs@b1-systems.com
- fix build on CentOS/RHEL by specifying TZ=UTC for %%check
- fix CentOS/RHEL by depending on /usr/sbin/update-alternatives
* Thu May 28 2015 toddrme2178@gmail.com
- Fix update-alternatives usage
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Fri Aug 15 2014 sfalken@opensuse.org
- Removed un-needed BuildRequire for timezone
* Fri Aug 15 2014 sfalken@opensuse.org
- Added 0001-disable_timezone_tests.patch
  + Disabling tests so package will build.  Tests can be re-enabled
    when upstream bug is resolved (gh#mitsuhiko/babel#106)
* Tue Jan  7 2014 speilicke@suse.com
- Bring back argparse requirement for SP3
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Sep 30 2013 speilicke@suse.com
- Implement update-alternatives
- Fix testsuite run on SLE and run it only once
- Properly build (and install) HTML documentation
* Mon Sep 30 2013 dmueller@suse.com
- make tests happy on openSUSE_12.2 (too old pytests)
* Fri Sep 27 2013 dmueller@suse.com
- update to 1.3.0:
  - support python 2.6, 2.7, 3.3+ and pypy - drop all other versions
  - use tox for testing on different pythons
  - Added support for the locale plural rules defined by the CLDR.
  - Added `format_timedelta` function to support localized formatting of
  relative times with strings such as "2 days" or "1 month" (ticket #126).
  - Fixed negative offset handling of Catalog._set_mime_headers (ticket #165).
  - Fixed the case where messages containing square brackets would break with
  an unpack error.
  - updated to CLDR 23
  - Make the CLDR import script work with Python 2.7.
  - Fix various typos.
  - Sort output of list-locales.
  - Make the POT-Creation-Date of the catalog being updated equal to
  POT-Creation-Date of the template used to update (ticket #148).
  - Use a more explicit error message if no option or argument (command) is
  passed to pybabel (ticket #81).
  - Keep the PO-Revision-Date if it is not the default value (ticket #148).
  - Make --no-wrap work by reworking --width's default and mimic xgettext's
  behaviour of always wrapping comments (ticket #145).
  - Add --project and --version options for commandline (ticket #173).
  - Add a __ne__() method to the Local class.
  - Explicitly sort instead of using sorted() and don't assume ordering
  (Jython compatibility).
  - Removed ValueError raising for string formatting message checkers if the
  string does not contain any string formattings (ticket #150).
  - Fix Serbian plural forms (ticket #213).
  - Small speed improvement in format_date() (ticket #216).
  - Fix so frontend.CommandLineInterface.run does not accumulate logging
  handlers (#227, reported with initial patch by dfraser)
  - Fix exception if environment contains an invalid locale setting (#200)
  - use cPickle instead of pickle for better performance (#225)
  - Only use bankers round algorithm as a tie breaker if there are two nearest
  numbers, round as usual if there is only one nearest number (#267, patch by
  Martin)
  - Allow disabling cache behaviour in LazyProxy (#208, initial patch from Pedro
  Algarvio)
  - Support for context-aware methods during message extraction (#229, patch
  from David Rios)
  - "init" and "update" commands support "--no-wrap" option (#289)
  - fix formatting of fraction in format_decimal() if the input value is a float
  with more than 7 significant digits (#183)
  - fix format_date() with datetime parameter (#282, patch from Xavier Morel)
  - fix format_decimal() with small Decimal values (#214, patch from George Lund)
  - fix handling of messages containing '\\n' (#198)
  - handle irregular multi-line msgstr (no "" as first line) gracefully (#171)
  - parse_decimal() now returns Decimals not floats, API change (#178)
  - no warnings when running setup.py without installed setuptools (#262)
  - modified Locale.__eq__ method so Locales are only equal if all of their
  attributes (language, territory, script, variant) are equal
  - resort to hard-coded message extractors/checkers if pkg_resources is
  installed but no egg-info was found (#230)
  - format_time() and format_datetime() now accept also floats (#242)
  - add babel.support.NullTranslations class similar to gettext.NullTranslations
  but with all of Babel's new gettext methods (#277)
  - "init" and "update" commands support "--width" option (#284)
  - fix 'input_dirs' option for setuptools integration (#232, initial patch by
  Étienne Bersac)
  - ensure .mo file header contains the same information as the source .po file
  (#199)
  - added support for get_language_name() on the locale objects.
  - added support for get_territory_name() on the locale objects.
  - added support for get_script_name() on the locale objects.
  - added pluralization support for currency names and added a '¤¤¤'
  pattern for currencies that includes the full name.
  - depend on pytz now and wrap it nicer.  This gives us improved support
  for things like timezone transitions and an overall nicer API.
  - Added support for explicit charset to PO file reading.
  - Added experimental Python 3 support.
  - Added better support for returning timezone names.
  - Don't throw away a Catalog's obsolete messages when updating it.
  - Added basic likelySubtag resolving when doing locale parsing and no
  match can be found.
- run tests
- use setuptools, not distribute
- add missing dependency on pytz
* Thu Sep  1 2011 saschpe@suse.de
- Fixed license to BSD-3-Clause (SPDX style)
* Thu Sep  1 2011 saschpe@suse.de
- Update to version 0.9.6:
  * Backport r493-494: documentation typo fixes.
  * Make the CLDR import script work with Python 2.7.
  * Fix various typos.
  * Fixed Python 2.3 compatibility (ticket #146, #233).
  * Sort output of list-locales.
  * Make the POT-Creation-Date of the catalog being updated equal to
    POT-Creation-Date of the template used to update (ticket #148).
  * Use a more explicit error message if no option or argument (command) is
    passed to pybabel (ticket #81).
  * Keep the PO-Revision-Date if it is not the default value (ticket #148).
  * Make --no-wrap work by reworking --width's default and mimic xgettext's
    behaviour of always wrapping comments (ticket #145).
  * Fixed negative offset handling of Catalog._set_mime_headers (ticket #165).
  * Add --project and --version options for commandline (ticket #173).
  * Add a __ne__() method to the Local class.
  * Explicitly sort instead of using sorted() and don't assume ordering
    (Python 2.3 and Jython compatibility).
  * Removed ValueError raising for string formatting message checkers if the
    string does not contain any string formattings (ticket #150).
  * Fix Serbian plural forms (ticket #213).
  * Small speed improvement in format_date() (ticket #216).
  * Fix number formatting for locales where CLDR specifies alt or draft
    items (ticket #217)
  * Fix bad check in format_time (ticket #257, reported with patch and tests by
    jomae)
  * Fix so frontend.CommandLineInterface.run does not accumulate logging
    handlers (#227, reported with initial patch by dfraser)
  * Fix exception if environment contains an invalid locale setting (#200)
- Renamed to python-Babel (from python-babel)
* Mon Dec 20 2010 saschpe@suse.de
- re-added dependency to python-setuptools
* Wed Dec 15 2010 saschpe@suse.de
- added documentation:
  * files: COPYING ChangeLog INSTALL.txt README.txt
  * HTML documentation
* Sat Dec 11 2010 saschpe@gmx.de
- re-generated spec file with py2pack:
  * now builds for Fedora and Mandriva
* Wed Sep  1 2010 jmatejek@novell.com
- added python-devel to buildrequires, to fix build on new python
  (because the package requires doctest, which requires unittest,
  which should probably both go into python-devel. (but this is
  subject to change))
- dropped check for obsolete SUSE version
* Sun Apr 25 2010 bitdealer@gmail.com
- Update to 0.9.5.
- Switch to noarch.
- Clean up spec.
